import { aws_apigateway as apigateway, aws_dynamodb as dynamodb, aws_ec2 as ec2, aws_iam as iam, aws_secretsmanager as secretsmanager } from "aws-cdk-lib";
import { PythonFunctionProps } from "@aws-cdk/aws-lambda-python-alpha";
import { Construct } from "constructs";
export declare class StacIngestor extends Construct {
    table: dynamodb.Table;
    handlerRole: iam.Role;
    constructor(scope: Construct, id: string, props: StacIngestorProps);
    private buildTable;
    private buildApiLambda;
    private buildIngestor;
    private buildApiEndpoint;
    private registerSsmParameter;
}
export interface StacIngestorProps {
    /**
     * ARN of AWS Role used to validate access to S3 data
     */
    readonly dataAccessRole: iam.IRole;
    /**
     * URL of STAC API
     */
    readonly stacUrl: string;
    /**
     * Stage of deployment (e.g. `dev`, `prod`)
     */
    readonly stage: string;
    /**
     * Secret containing pgSTAC DB connection information
     */
    readonly stacDbSecret: secretsmanager.ISecret;
    /**
     * VPC running pgSTAC DB
     */
    readonly vpc: ec2.IVpc;
    /**
     * Security Group used by pgSTAC DB
     */
    readonly stacDbSecurityGroup: ec2.ISecurityGroup;
    /**
     * Boolean indicating whether or not pgSTAC DB is in a public subnet
     */
    readonly subnetSelection: ec2.SubnetSelection;
    /**
     * Environment variables to be sent to Lambda.
     */
    readonly apiEnv?: Record<string, string>;
    /**
     * API Endpoint Configuration, useful for creating private APIs.
     */
    readonly apiEndpointConfiguration?: apigateway.EndpointConfiguration;
    /**
     * API Policy Document, useful for creating private APIs.
     */
    readonly apiPolicy?: iam.PolicyDocument;
    /**
     * Custom Domain Name Options for Ingestor API
     */
    readonly ingestorDomainNameOptions?: apigateway.DomainNameOptions;
    /**
     * Custom code for the ingestor api.
     *
     * @default - default in the runtime folder.
     */
    readonly apiCode?: ApiCode;
    /**
    * Custom code for the ingestor.
    *
    * @default - default in the runtime folder.
    */
    readonly ingestorCode?: IngestorCode;
}
export interface ApiCode {
    /**
     * Path to the source of the function or the location for dependencies, for the api lambda.
     */
    readonly entry: PythonFunctionProps["entry"];
    /**
     * Path to the index file containing the exported handler, relative to `api_lambda_entry`.
     */
    readonly index: PythonFunctionProps["index"];
    /**
     * The name of the exported handler in the `api_lambda_index` file.
     */
    readonly handler: PythonFunctionProps["handler"];
}
export interface IngestorCode {
    /**
     * Path to the source of the function or the location for dependencies, for the ingestor lambda.
     */
    readonly entry: PythonFunctionProps["entry"];
    /**
     * Path to the index file containing the exported handler, relative to `ingestor_lambda_entry`.
     */
    readonly index: PythonFunctionProps["index"];
    /**
     * The name of the exported handler in the `ingestor_lambda_index` file.
     */
    readonly handler: PythonFunctionProps["handler"];
}
