import { aws_ec2 as ec2, aws_rds as rds, aws_lambda as lambda, aws_secretsmanager as secretsmanager, BundlingOptions } from "aws-cdk-lib";
import { Runtime } from 'aws-cdk-lib/aws-lambda';
import { IDomainName } from "@aws-cdk/aws-apigatewayv2-alpha";
import { Construct } from "constructs";
export declare class TitilerPgstacApiLambda extends Construct {
    readonly url: string;
    titilerPgstacLambdaFunction: lambda.Function;
    constructor(scope: Construct, id: string, props: TitilerPgStacApiLambdaProps);
}
export interface TitilerPgStacApiLambdaProps {
    /**
     * VPC into which the lambda should be deployed.
     */
    readonly vpc: ec2.IVpc;
    /**
     * RDS Instance with installed pgSTAC.
     */
    readonly db: rds.IDatabaseInstance;
    /**
     * Subnet into which the lambda should be deployed.
     */
    readonly subnetSelection: ec2.SubnetSelection;
    /**
     * Secret containing connection information for pgSTAC database.
     */
    readonly dbSecret: secretsmanager.ISecret;
    /**
     * Customized environment variables to send to titiler-pgstac runtime. These will be merged with `defaultTitilerPgstacEnv`.
     * The database secret arn is automatically added to the environment variables at deployment.
    /*/
    readonly apiEnv?: Record<string, string>;
    /**
     * list of buckets the lambda will be granted access to.
     */
    readonly buckets?: string[];
    /**
     * Custom Domain Name Options for Titiler Pgstac API,
     *
     * @default - undefined.
     */
    readonly titilerPgstacApiDomainName?: IDomainName;
    /**
     * Optional settings for the titiler-pgstac python lambda function.
     *
     * @default - defined in the construct.
     */
    readonly pythonLambdaOptions?: TitilerPgstacPythonLambdaOptions;
}
export interface TitilerPgstacPythonLambdaOptions {
    /**
     * Path to the source of the function or the location for dependencies.
     */
    readonly entry: string;
    /**
     * The runtime environment. Only runtimes of the Python family are
     * supported.
     */
    readonly runtime: Runtime;
    /**
     * The path (relative to entry) to the index file containing the exported handler.
     *
     */
    readonly index: string;
    /**
     * The name of the exported handler in the index file.
     */
    readonly handler: string;
    /**
     * Bundling options to use for this function. Use this to specify custom bundling options like
     * the bundling Docker image, asset hash type, custom hash, architecture, etc.
     */
    readonly bundling?: BundlingOptions;
    /**
     * The amount of memory, in MB, that is allocated to your Lambda function.
     */
    readonly memorySize: number;
    /**
     * The system architectures compatible with this lambda function.
     */
    readonly architecture: lambda.Architecture;
}
